@@ -1,7 +1,7 @@
 /*
 ** hash.c - functions for a hash table.
 **
-** Copyright (c) 1996, 1997 Thorsten Kukuk
+** Copyright (c) 1996, 1997, 1999 Thorsten Kukuk
 **
 ** This file is part of the NYS YP Server.
 **
@@ -20,23 +20,16 @@
 ** not, write to the Free Software Foundation, Inc., 675 Mass Ave,
 ** Cambridge, MA 02139, USA.
 **
-** Author: Thorsten Kukuk <kukuk@uni-paderborn.de>
+** Author: Thorsten Kukuk <kukuk@suse.de>
 */
 
-#ifndef LINT
-static const char rcsid[] = "$Id: hash.c,v 1.5 1997/05/02 16:34:14 kukuk Exp $";
-#endif
-
-#if 0
-#define DEBUG_HASH
-#endif
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
-#include <malloc.h>
 #include "hash.h"
 #include <assert.h>
 
@@ -75,7 +68,7 @@ hash_malloc (void)
  *
  *   Calculates the key, returns it.
  */
-inline long
+static inline long
 hash_calc_key (const char *key)
 {
   long hkey = 0;
@@ -97,7 +90,7 @@ hash_calc_key (const char *key)
  *   at it's entry in the table.
  */
 int
-hash_insert (hash_t ** table, const char *key, const char *val)
+hash_insert (hash_t **table, const char *key, const char *val)
 {
   long hkey = -1;
   hash_t *work = NULL;
@@ -150,7 +143,7 @@ hash_insert (hash_t ** table, const char *key, const char *val)
  *
  */
 int
-hash_free (hash_t ** table)
+hash_free (hash_t **table __attribute__ ((unused)))
 {
   /* XXX Not implementet yet! */
 
@@ -166,7 +159,7 @@ hash_free (hash_t ** table)
  *
  */
 char *
-hash_search (hash_t ** table, const char *key)
+hash_search (hash_t **table, const char *key)
 {
   hash_t *work = NULL;
   long hkey = -1;
@@ -196,7 +189,7 @@ hash_search (hash_t ** table, const char *key)
  *   Delete the item from the table.
  */
 int
-hash_delkey (hash_t ** table, const char *key)
+hash_delkey (hash_t **table, const char *key)
 {
   hash_t *work = NULL;
   hash_t *prev = NULL;
@@ -241,7 +234,7 @@ hash_delkey (hash_t ** table, const char *key)
  *   Returns the first item in the hash table.
  */
 hash_t *
-hash_first (hash_t ** table)
+hash_first (hash_t **table)
 {
   unsigned long i = 0;
 
@@ -260,7 +253,7 @@ hash_first (hash_t ** table)
  *   Returns the next item in the cache.
  */
 hash_t *
-hash_next (hash_t ** table, const char *key)
+hash_next (hash_t **table, const char *key)
 {
   hash_t *work = NULL;
   long hkey = -1;
